<?php
class OC_Stripe_Admin
{
    /**
     * Add admin form for Stripe variable modifications
     *
     * @param object $form
     * @return string
     */
    public function getStripeForm($form)
    {
        $stripe = function () use ($form) {
            echo '<p>' . esc_html__('If you are wanting to use Stripe as a integrated method of Payment after a contract is signed, use the following section to provide a bit of information for our plugin to use, otherwise leave this section blank.', 'onlinecontractstripe') . '</p>';
            echo '<p style="color:red;"><strong>' . esc_html__('NOTE: If you are using the live keys, an SSL for your website is required to process the payment.', 'onlinecontractstripe') . '</strong></p>';
            echo $form->text(esc_html__('Stripe Public API Key', 'onlinecontractstripe'));
            echo $form->text(esc_html__('Stripe Private API Key', 'onlinecontractstripe'));
            echo $form->text(esc_html__('Stripe Fee', 'onlinecontractstripe'));
            echo $form->text(esc_html__('Stripe Button Label', 'onlinecontractstripe'));
            echo $form->checkbox(esc_html__('Turn Off Stripe?', 'onlinecontractstripe'));
            echo '<br>';
            echo '
            <h3>' . esc_html__('Stripe Payment Integration', 'onlinecontractstripe') . '</h3>
            <p>' . esc_html__('Thank you for using our Stripe payments addon for our Online Contract plugin. Remember, this plugin will only work with our WP Online Contract plugin.  If you purchased this plugin without that plugin, you can purchase our contract plugin using the following link', 'onlinecontractstripe') . ':<br>
            <a href="https://codecanyon.net/item/wp-online-contract/7698011?ref=futuredesigngrp" target="_blank">https://codecanyon.net/item/wp-online-contract/7698011</a></p>
            <p>' . esc_html__('Interested in more of our plugins? Please take a look at our CodeCanyon portfolio for all of our plugins and code', 'onlinecontractstripe') . ':<br>
            <a href="https://codecanyon.net/user/futuredesigngrp/portfolio?ref=futuredesigngrp" target="_blank">https://codecanyon.net/user/futuredesigngrp/portfolio</a></p>
            <h3>' . esc_html__('About Stripe', 'onlinecontractstripe') . '</h3>
            <p>' . esc_html__('Stripe is a developer-friendly way to accept payments online and in mobile apps. We process billions of dollars a year for thousands of companies of all sizes.', 'onlinecontractstripe') . '</p>
            <p><a href="https://stripe.com/about" target="_blank">' . esc_html__('Read more about Stripe', 'onlinecontractstripe') . '</a></p>
            <h3>' . esc_html__('Signup for Stripe', 'onlinecontractstripe') . '</h3>
            <p>' . esc_html__('If you do not have a Stripe account? No problem.  Sign up on their website using the link below', 'onlinecontractstripe') . ':<br>
            <a href="https://dashboard.stripe.com/register" target="_blank">www.stripe.com</a></p>
            <h3>' . esc_html__('Get Your Stripe Keys', 'onlinecontractstripe') . '</h3>
            <p>' . esc_html__('Click the following link to retrieve your public and secret keys. If you have admin access, they should be present in your account.  If not, you may only have read write access and you will have to contact your developer r the person that setup your account to access the API keys for you. In order for this plugin to work properly and process charges, both keys are required.', 'onlinecontractstripe') . '</p>
            <p>' . esc_html__('Please select the "live" keys in order to make your plugin payments live.  You can test using the test keys, but you will not be able to process live credit cards until you have entered the live keys.', 'onlinecontractstripe') . '<br><a href="https://dashboard.stripe.com/account/apikeys" target="_blank" onclick="return makesureSave();">https://dashboard.stripe.com/account/apikeys</a></p>
            <p style="text-align:right">Version: ' . ONLINE_CONTRACT_STRIPE_VERSION_NUMBER . '</p>
            ';
        };
        return $stripe;
    }

    /**
     * Notice displayed if WP Online Contract is not installed
     *
     * @return void
     */
    public function oc_stripe_notice()
    {
        echo '<div class="notice notice-error">
            <p>' . esc_html__('In order to use the Online Contract Stripe Payments Integration plugin, you must install WP Online Contract. It is useless without it.', 'onlinecontractstripe') . '</p>
        </div>';
    }

    /**
     * Checks if WP Online Contract is installed
     *
     * @return bool
     */
    public function is_oc_installed(): bool
    {
        if ($this->check_plugin_installed('onlinecontract/onlinecontract.php')) {
            return true;
        }

        return false;
    }

    /**
     * Check if WP Online Contract is activated
     *
     * @return bool
     */
    public function is_oc_active(): bool
    {
        if ($this->check_plugin_active('onlinecontract/onlinecontract.php')) {
            return true;
        }

        return false;
    }

    /**
     * Check if plugin is installed by getting all plugins from the plugins dir
     *
     * @param $plugin_slug
     *
     * @return bool
     */
    public function check_plugin_installed($plugin_slug): bool
    {
        $installed_plugins = get_plugins();

        return array_key_exists($plugin_slug, $installed_plugins) || in_array($plugin_slug, $installed_plugins, true);
    }

    /**
     * Check if plugin is installed
     *
     * @param string $plugin_slug
     *
     * @return bool
     */
    public function check_plugin_active($plugin_slug): bool
    {
        if (is_plugin_active($plugin_slug)) {
            return true;
        }

        return false;
    }
}
