<?php
class OC_Stripe_Frontend
{
    /**
     * Display Stripe button on the front end after a contract is signed
     *
     * @param array $settings
     * @param class $frontend
     * @param class $Parser
     * @param string $amount
     * @param string $itemname
     * @return string
     */
    public function getStripeButton($settings, $frontend, $Parser, $amount, $itemname)
    {
        $fontAwesome = '';
        $zipCode = '';
        $amount = $frontend->formatTemplate('[' . $amount . ']');
        $stripefee = tr_options_field('fdg_payment_options.stripe_fee');
        $stripePublicKey = tr_options_field('fdg_payment_options.stripe_public_api_key');
        $stripeButtonLabel = tr_options_field('fdg_payment_options.stripe_button_label');
        $stripeRequireZipCode = tr_options_field('fdg_payment_options.stripe_require_zip_code?');
        $stripeLogo = tr_options_field('fdg_payment_options.stripe_checkout_icon');

        if (strpos($stripefee, '%') !== false) {
            $stripefee = str_replace('%', '', $stripefee);
            $stripetotal = round($Parser->Execute($amount * ($stripefee / 100)), $settings['decimalRound']);
            $stripetotal =  round($Parser->Execute($amount + $stripetotal), $settings['decimalRound']);
        } else {
            $stripetotal =  round($Parser->Execute($amount + $stripefee), $settings['decimalRound']);
        }
        $stripetotal = $Parser->Execute($stripetotal * 100);
        $itemname = $frontend->formattemplate('[' . $itemname . ']');
        $currency = $settings['currencyType'];
        $icon = wp_get_attachment_image_src($stripeLogo);
        if ($icon[0] == NULL || $icon[0] == '') {
            $icon = 'https://stripe.com/img/documentation/checkout/marketplace.png';
        } else {
            $icon = $icon[0];
        }
        if ($settings['fontAwesome'] == 1) {
            $fontAwesome = '<em class="fab fa-stripe" aria-hidden="true"></em> ';
        }
        if ($stripeRequireZipCode == 1) {
            $zipCode = 'zipCode: true,';
        }
        $stripebutton = '<button type="button" id="checkout-button" class="btn button stripe">' . $fontAwesome . $stripeButtonLabel . '</button>';
        $stripebutton .= '
        <script src="https://js.stripe.com/v3/"></script>
        <script type="text/javascript">
            var stripe = Stripe("' . $stripePublicKey . '");
            var checkoutButton = document.getElementById("checkout-button");

            checkoutButton.addEventListener("click", function () {
            fetch("' . ONLINE_CONTRACT_STRIPE_URL . 'stripe-session.php?ret=' . get_the_permalink() . '&price=' . $stripetotal . '&itemname=' . $itemname . '&currency=' . $currency . '", {
                method: "POST",
            })
                .then(function (response) {
                return response.json();
                })
                .then(function (session) {
                return stripe.redirectToCheckout({ sessionId: session.id });
                })
                .then(function (result) {
                if (result.error) {
                    alert(result.error.message);
                }
                })
                .catch(function (error) {
                console.error("Error:", error);
                });
            });
        </script>';
        return $stripebutton;
    }
}
